require 'spec_helper'

describe Tomahawk::DirectiveGroups::Base do
  it 'can get initialized' do
    config = Tomahawk::DirectiveGroups::Base.new('abcd', { 'server_name' => 'example.com', 'foo' => 'bar'})

    expect(config.directives['server_name']).to eq('example.com')
    expect(config.directives['foo']).to eq('bar')
  end

  it 'can get initialized by block' do
    config = Tomahawk::DirectiveGroups::Base.new do |directives, groups|
      directives['server_name'] = 'example.com'
      directives['foo'] = 'bar'

      groups << Tomahawk::DirectiveGroups::Base.new do |directives, groups|
        directives['group_test'] = 'works'
      end
    end

    expect(config.directives['server_name']).to eq('example.com')
    expect(config.directives['foo']).to eq('bar')
    expect(config.groups.first.directives['group_test']).to eq('works')
  end

  it 'forwards #to_s/#to_str messages to a generator' do
    config = Tomahawk::DirectiveGroups::HTTPd.new

    expect(Tomahawk::Generators::HTTPd).to receive(:new).exactly(2).times

    config.to_s # explicitly
    "#{config}" # implicitly
  end
end